@@ -85,7 +85,7 @@ LBLPROTDISP = "Protocols Shown"
 LBLDATADISP = "Console Display"
 LBLUBXCONFIG = "UBX\nConfig"
 LBLNTRIPCONFIG = "NTRIP\nClient"
-LBLNTRIPGGAINT = "GGA Interval"
+LBLNTRIPGGAINT = "GGA Interval s"
 LBLCTL = "Controls"
 LBLSET = "Settings"
 LBLCFGPRT = "CFG-PRT Protocol Configuration"
@@ -108,6 +108,9 @@ LBLSOCKSERVE = "Socket Server /\nNTRIP Caster   "  # padded to align
 LBLSERVERPORT = "Port"
 LBLDEGFORMAT = "Degrees Format"
 LBLSERVERMODE = "Mode"
+LBLCFGDYN = "CFG-* Other Configuration"
+LBLGGALIVE = "Receiver"
+LBLGGAFIXED = "Fixed Reference"
 
 # Dialog text
 DLGUBXCONFIG = "UBX Configuration"
